from typing import override

from archinstall.default_profiles.profile import GreeterType, ProfileType
from archinstall.default_profiles.xorg import XorgProfile


class CosmicProfile(XorgProfile):
	def __init__(self) -> None:
		super().__init__('cosmic-epoch', ProfileType.DesktopEnv, advanced=True)

	@property
	@override
	def packages(self) -> list[str]:
		return [
			'cosmic',
		]

	@property
	@override
	def default_greeter_type(self) -> GreeterType:
		return GreeterType.CosmicSession
